@@ -12,7 +12,7 @@ require XSLoader;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(minify);
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.2.0';
 
 XSLoader::load( "Text::Minify::XS", $VERSION );
 
@@ -30,7 +30,7 @@ Text::Minify::XS - Simple text minification
 
 =head1 VERSION
 
-version v0.1.0
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -44,9 +44,24 @@ version v0.1.0
 
   my $out = minify( $in );
 
-This performs a quick-and-dirty text minifying.
+This is a quick-and-dirty text minifier that removes whitespace in a
+single pass.
 
-Currently, it only removes leading whitespace and multiple newlines.
+It does the following:
+
+=over
+
+=item removes leading whitespace (indentation),
+
+=item removes trailing whitespace,
+
+=item removes multiple newlines,
+
+=item and changes all line endings to a newline, "\n",
+
+=back
+
+It does not know recognise any form of markup, comments or text quoting.
 
 =head1 KNOWN ISSUES
 
